@@ -4,7 +4,11 @@ Metrics utilities public api
 See README.rst for details.
 """
 from .internal.code_owner.middleware import CodeOwnerMonitoringMiddleware
-from .internal.code_owner.utils import get_code_owner_from_module
+from .internal.code_owner.utils import (
+    get_code_owner_from_module,
+    set_code_owner_attribute,
+    set_code_owner_attribute_from_module
+)
 from .internal.middleware import CachedCustomMonitoringMiddleware, MonitoringMemoryMiddleware
 from .internal.transactions import (
     function_trace,
@@ -12,6 +16,12 @@ from .internal.transactions import (
     ignore_transaction,
     set_monitoring_transaction_name
 )
-from .internal.utils import accumulate, increment, set_custom_attribute, set_custom_attributes_for_course_key
+from .internal.utils import (
+    accumulate,
+    increment,
+    record_exception,
+    set_custom_attribute,
+    set_custom_attributes_for_course_key
+)
 # "set_custom_metric*" methods are deprecated
 from .utils import set_custom_metric, set_custom_metrics_for_course_key
