@@ -6,7 +6,13 @@ from django.test import TestCase
 from mock import call, patch
 
 from edx_django_utils.cache import RequestCache
-from edx_django_utils.monitoring import CachedCustomMonitoringMiddleware, accumulate, get_current_transaction, increment
+from edx_django_utils.monitoring import (
+    CachedCustomMonitoringMiddleware,
+    accumulate,
+    get_current_transaction,
+    increment,
+    record_exception
+)
 
 from ..middleware import CachedCustomMonitoringMiddleware as DeprecatedCachedCustomMonitoringMiddleware
 from ..middleware import MonitoringCustomMetricsMiddleware as DeprecatedMonitoringCustomMetricsMiddleware
@@ -137,3 +143,8 @@ class TestCustomMonitoringMiddleware(TestCase):
     def test_deprecated_set_custom_attributes_for_course_key(self, mock_set_custom_attributes_for_course_key):
         deprecated_set_custom_attributes_for_course_key('key')
         mock_set_custom_attributes_for_course_key.assert_called_with('key')
+
+    @patch('newrelic.agent.record_exception')
+    def test_record_exception(self, mock_record_exception):
+        record_exception()
+        mock_record_exception.assert_called_once()
